import { useEffect, useState } from "react";
import CalendarRow from "./CalendarRow/CalendarRow";
import CalendarSmallCell from "./CalendarSmallCell/CalendarSmallCell";
import CalendarStandartCell from "./CalendarStandartCell.js/CalendarStandartCell";
import CalendarTask from "./CalendarTask/CalendarTask";

function MonthCalendarBody({month, year, tasks, createTaskInCellHandler, onChangeCellTaskTitle, setCurrentTask}) {
  
  const [hoursInDay, setHoursInDay] = useState(['8:00', '10:00', '12:00', '14:00', '16:00', '18:00', '20:00', '22:00', '6:00'])
  const [daysInMonth, setDaysInMonth] = useState([])
  const [cellSizes, setCellSizes] = useState({})

  useEffect(()=>{
    const cells = hoursInDay.length
    const xs = 11/cells
    setCellSizes(()=>{
      return {smallCell: 0.5, standarCell: xs}
    })
  }, [])

  useEffect(()=>{
    setNewMonthDays()
  }, [month])

  const getDaysInMonth = () => { 
    return new Date(year, month + 1, 0).getDate();
  }

  const getDayOfWeekString = (day) => {
    return ["ВС","ПН","ВТ","СР","ЧТ","ПТ","СБ"][day];
  }

  const getDayOfWeekNumber = (day) => {
    return new Date(year, month, day).getDay()
  }

  const setNewMonthDays = () => {
    const newDaysInMonth = []
    for (let i = 1; i <= getDaysInMonth(); i++) {
      const dayOfWeekNumber = getDayOfWeekNumber(i)
      newDaysInMonth.push({dayNumber: i, dayOfWeek: getDayOfWeekString(dayOfWeekNumber)})
    }
    setDaysInMonth(prevState=>newDaysInMonth)
  }

  return (
    <>
    <CalendarRow
      >
        <CalendarSmallCell xs={cellSizes.smallCell} />
        <CalendarSmallCell xs={cellSizes.smallCell}/>
        {hoursInDay.map((hours, i)=>{
          return (
            <CalendarStandartCell key={i} xs={cellSizes.standarCell}>
              {hours}
            </CalendarStandartCell>
            ) 
          })}
    </CalendarRow>
    {daysInMonth.map((day, i)=>{
      return (
        <CalendarRow
          key={i}
          >
            <CalendarSmallCell xs={cellSizes.smallCell}>{day.dayNumber}</CalendarSmallCell>
            <CalendarSmallCell xs={cellSizes.smallCell}>{day.dayOfWeek}</CalendarSmallCell>
            {hoursInDay.map((hours, i)=>{
              return (
                <CalendarStandartCell 
                  key={i} 
                  item xs={cellSizes.standarCell}
                  onClick={()=>{createTaskInCellHandler(day.dayNumber, hours)}}
                  >
                    <CalendarTask
                      setCurrentTask={setCurrentTask}
                      onChange={(e)=>{onChangeCellTaskTitle(e)}}
                      year={year}
                      month={month} 
                      tasks={tasks}
                      day={day}
                      hours={hours}
                    />
                </CalendarStandartCell>
                ) 
              })}
        </CalendarRow>
      )
    })}
    </>
  );
}

export default MonthCalendarBody;